import setuptools

with open("README.md", "r") as file:
    long_description = file.read()

setuptools.setup(
    name="center_tk_window",
    version="1.0.0",
    author="Jarik Marwede",
    author_email="jarikmarwede@zoho.eu",
    description="Functions for centering tkinter windows on parent or on screen",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jarikmarwede/center-tk-window",
    packages=setuptools.find_packages(),
    py_modules=["center_tk_window"],
    package_dir={"": "src"},
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ]
)



import tkinter
from typing import Union


def center_on_screen(window: Union[tkinter.Tk, tkinter.Toplevel]):
    """Center a window on the screen."""
    window.update_idletasks()
    width = window.winfo_width()
    height = window.winfo_height()
    x_coordinate = int(window.winfo_screenwidth() / 2 - width / 2)
    y_coordinate = int(window.winfo_screenheight() / 2 - height / 2)

    window.geometry(f"{width}x{height}+{x_coordinate}+{y_coordinate}")


def center_on_parent(root: tkinter.Tk, window: tkinter.Toplevel):
    """Center a window on its parent."""
    window.update_idletasks()
    height = window.winfo_height()
    width = window.winfo_width()
    parent = root.nametowidget(window.winfo_parent())
    x_coordinate = int(parent.winfo_x() + (parent.winfo_width() / 2 - width / 2))
    y_coordinate = int(parent.winfo_y() + (parent.winfo_height() / 2 - height / 2))

    window.geometry(f"{width}x{height}+{x_coordinate}+{y_coordinate}")


def center(root: tkinter.Tk, window: Union[tkinter.Tk, tkinter.Toplevel]):
    """Center a window on its parent or the screen if there is no parent."""
    if window.winfo_parent():
        center_on_parent(root, window)
    else:
        center_on_screen(window)
